@@ -1,7 +1,8 @@
-use types::Value;
+use types::{CallbackPtr, CallbackMutPtr, Value};
 
 extern "C" {
     pub fn rb_hash_aref(hash: Value, key: Value) -> Value;
     pub fn rb_hash_aset(hash: Value, key: Value, value: Value) -> Value;
+    pub fn rb_hash_foreach(hash: Value, callback: CallbackPtr, pass: CallbackMutPtr);
     pub fn rb_hash_new() -> Value;
 }
